@@ -21,15 +21,27 @@ OC.L10N.register(
     "Invalid directory." : "Ungültiges Verzeichnis.",
     "Files" : "Dateien",
     "All files" : "Alle Dateien",
-    "Favorites" : "Favoriten",
+    "File could not be found" : "Datei konnte nicht gefunden werden",
     "Home" : "Home",
     "Close" : "Schließen",
+    "Favorites" : "Favoriten",
     "Upload cancelled." : "Upload abgebrochen.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
     "Total file size {size1} exceeds upload limit {size2}" : "Die Gesamt-Größe {size1} überschreitet die Upload-Begrenzung {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, du möchtest {size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
     "Error uploading file \"{fileName}\": {message}" : "Fehler beim Hochladen von \"{fileName}\": {message}",
     "Could not get result from server." : "Ergebnis konnte nicht vom Server abgerufen werden.",
+    "Uploading..." : "Hochladen…",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} Stunde{plural_s} übrig",
+    "{hours}:{minutes}h" : "{hours}:{minutes}h",
+    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} Minute{plural_s} übrig",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
+    "{seconds} second{plural_s} left" : "{seconds} Sekund{plural_s} übrig",
+    "{seconds}s" : "{seconds}n",
+    "Any moment now..." : "Jeden Augenblick...",
+    "Soon..." : "Bald...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Dateiupload läuft. Wenn Du die Seite jetzt verlässt, wird der Upload abgebrochen.",
     "Actions" : "Aktionen",
     "Download" : "Herunterladen",
@@ -75,6 +87,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
     "Favorited" : "Favorisiert",
     "Favorite" : "Favorit",
+    "Local link" : "Lokaler Link",
     "Folder" : "Ordner",
     "New folder" : "Neuer Ordner",
     "{newname} already exists" : "{newname} existiert bereits",
@@ -105,9 +118,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Mit PHP-FPM kann es bis zu 5 Minuten dauern, bis die Einstellungen übernommen werden.",
     "Missing permissions to edit from here." : "Fehlende Berechtigungen um von hier aus zu bearbeiten.",
     "Settings" : "Einstellungen",
+    "Show hidden files" : "Versteckte Dateien anzeigen",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Benutze diese Adresse, um <a href=\"%s\" target=\"_blank\">über WebDAV auf Deine Dateien zuzugreifen</a>",
-    "Cancel upload" : "Upload abbrechen",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Benutze diese Adresse, um <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">über WebDAV auf Deine Dateien zuzugreifen</a>",
     "No files in here" : "Keine Dateien vorhanden",
     "Upload some content or sync with your devices!" : "Lade Inhalte hoch oder synchronisiere mit Deinen Geräten!",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner",
