@@ -4,14 +4,13 @@ OC.L10N.register(
     "Server to server sharing is not enabled on this server" : "Server til server-deling er ikke aktivert på denne serveren",
     "The mountpoint name contains invalid characters." : "Navnet på oppkoblingspunktet inneholder ugyldige tegn.",
     "Not allowed to create a federated share with the same user server" : "Ikke tillatt å opprette en Sammenknyttet sky-deling med den samme bruker-serveren",
-    "Invalid or untrusted SSL certificate" : "Ugyldig eller ikke tiltrodd SSL-sertifikat",
+    "Invalid or untrusted SSL certificate" : "Ugyldig eller ikke-klarert SSL-sertifikat",
     "Could not authenticate to remote share, password might be wrong" : "Klarte ikke å autentisere mot ekstern deling. Passordet kan være feil",
     "Storage not valid" : "Lagerplass ikke gyldig",
     "Couldn't add remote share" : "Klarte ikke å legge til ekstern deling",
     "Shared with you" : "Delt med deg",
     "Shared with others" : "Delt med andre",
     "Shared by link" : "Delt med lenke",
-    "Federated sharing" : "Sammenknyttet deling",
     "Nothing shared with you yet" : "Ingenting er delt med deg ennå",
     "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
     "Nothing shared yet" : "Ingenting er delt ennå",
@@ -28,6 +27,25 @@ OC.L10N.register(
     "Invalid ownCloud url" : "Ugyldig ownCloud-url",
     "Shared by" : "Delt av",
     "Sharing" : "Deling",
+    "Share API is disabled" : "Delings-API er deaktivert",
+    "Wrong share ID, share doesn't exist" : "Feil delings-ID, delingen finnes ikke",
+    "Could not delete share" : "Klarte ikke å slette deling",
+    "Please specify a file or folder path" : "Vennligst angi sti til en fil eller mappe",
+    "Wrong path, file/folder doesn't exist" : "Feil sti, fil/mappe finnest ikke",
+    "Please specify a valid user" : "Vennligst angi en gyldig bruker",
+    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktivert av administratoren",
+    "Please specify a valid group" : "Vennligst angi en gyldig gruppe",
+    "Public link sharing is disabled by the administrator" : "Deling med offentlig lenke er deaktivert av administratoren",
+    "Public upload disabled by the administrator" : "Deling med offentlig opplasting er deaktivert av administratoren",
+    "Public upload is only possible for publicly shared folders" : "Offentlig opplasting er kun mulig for offentlig delte mapper",
+    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato, datoformatet må være ÅÅÅÅ-MM-DD",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Deling av %s feilet, fordi serveren ikke tillater delinger fra type %s",
+    "Unknown share type" : "Ukjent delingstype",
+    "Not a directory" : "Ikke en katalog",
+    "Could not lock path" : "Klarte ikke å låse stien",
+    "Can't change permissions for public share links" : "Kan ikke endre rettigheter for offentlig delte lenker",
+    "Wrong or no update parameter given" : "Feil eller ingen oppdateringsparameter angitt",
+    "Cannot increase permissions" : "Kan ikke øke tillatelser",
     "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "En offentlig delt fil eller mappe ble <strong>lastet ned</strong>",
@@ -71,11 +89,6 @@ OC.L10N.register(
     "Public link of %2$s expired" : "Offentlig lenke til %2$s er utløpt",
     "Shared by %2$s" : "Delt av %2$s",
     "Shares" : "Delinger",
-    "You received \"/%2$s\" as a remote share from %1$s" : "Du mottok \"/%2$s\" som en ekstern deling fra %1$s",
-    "Accept" : "Aksepter",
-    "Decline" : "Avslå",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Del med meg gjennom min #ownCloud ID for sammenknyttet sky, se %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Del med meg gjennom min #ownCloud ID for sammenknyttet sky",
     "This share is password-protected" : "Denne delingen er passordbeskyttet",
     "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
     "Password" : "Passord",
@@ -91,29 +104,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Legg til i din ownCloud",
     "Download" : "Last ned",
     "Download %s" : "Last ned %s",
-    "Direct link" : "Direkte lenke",
-    "Federated Cloud Sharing" : "Sammenknyttet sky-deling",
-    "Open documentation" : "Åpne dokumentasjonen",
-    "Allow users on this server to send shares to other servers" : "Tillat at brukere på denne serveren sender delinger til andre servere",
-    "Allow users on this server to receive shares from other servers" : "Tillat at brukere på denne serveren mottar delinger fra andre servere",
-    "Federated Cloud" : "Sammenknyttet sky",
-    "Your Federated Cloud ID:" : "Din ID for sammenknyttet sky:",
-    "Share it:" : "Del den:",
-    "Add to your website" : "Legg på websiden din",
-    "Share with me via ownCloud" : "Del med meg via ownCloud",
-    "HTML Code:" : "HTML-kode:",
-    "Public link of %2$s expired" : "Offentlig lenke til %2$s er utløpt",
-    "Public shared file %1$s was downloaded" : "Offentlig delt fil %1$s ble lastet ned",
-    "Public shared folder %1$s was downloaded" : "Offentlig delt mappe %1$s ble lastet ned",
-    "Removed share for %2$s" : "Fjernet deling for %2$s",
-    "Removed share of group %2$s" : "Fjernet deling av gruppe %2$s",
-    "Shared by %2$s" : "Delt av %2$s",
-    "Shared via link by %2$s" : "Delt via lenke av %2$s",
-    "Shared with group %3$s by %2$s" : "Delt med gruppe %3$s av %2$s",
-    "The public link of %2$s for %1$s expired" : "Den offentlige lenken til %2$s for %1$s er utløpt",
-    "You removed the public link for %1$s" : "Du fjernet den offentlige lenken for %1$s",
-    "You removed the share of %2$s for %1$s" : "Du fjernet deling av %2$s for %1$s",
-    "You removed the share of group %2$s for %1$s" : "Du fjernet deling av gruppe %2$s for %1$s",
-    "Your public link for %1$s expired" : "Din offentlige lenke for %1$s er utløpt"
+    "Direct link" : "Direkte lenke"
 },
 "nplurals=2; plural=(n != 1);");
