@@ -8,13 +8,14 @@ OC.L10N.register(
     "Delete" : "Usuń",
     "Delete permanently" : "Trwale usuń",
     "Error" : "Błąd",
+    "This operation is forbidden" : "Ta operacja jest niedozwolona",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem.",
     "restored" : "przywrócony",
     "No deleted files" : "Brak skasowanych plików",
     "You will be able to recover deleted files from here" : "Możesz przywrócić skasowane pliki stąd",
     "No entries found in this folder" : "Brak wpisów w tym folderze",
     "Select all" : "Wybierz wszystko",
     "Name" : "Nazwa",
-    "Deleted" : "Usunięte",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem."
+    "Deleted" : "Usunięte"
 },
 "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
