@@ -1,15 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Неуспешно изпращане на имейл до следните потребители: %s.",
-    "Turned on maintenance mode" : "Режим за поддръжка е включен",
-    "Turned off maintenance mode" : "Режим за поддръжка е изключен",
-    "Updated database" : "Базата данни е обоновена",
-    "Checked database schema update" : "Обновяването на схемата на базата данни е проверено",
-    "Checked database schema update for apps" : "Обновяването на схемата на базата данни за приложения е проверено",
-    "Updated \"%s\" to %s" : "Обновен \"%s\" до %s",
-    "Repair warning: " : "Предупреждение при поправка:",
-    "Repair error: " : "Грешка при поправка:",
     "Invalid file provided" : "Предоставен е невалиден файл",
     "No image or file provided" : "Не бяха доставени картинка или файл",
     "Unknown filetype" : "Непознат файлов тип",
@@ -20,6 +11,22 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, уверете се, че потребителското име е правилно.",
     "%s password reset" : "Паролата на %s е променена.",
     "Couldn't send reset email. Please contact your administrator." : "Изпращането на електронна поща е неуспешно. Моля, свържете се с вашия администратор.",
+    "Error loading tags" : "Грешка при зареждане на етикети",
+    "Tag already exists" : "Етикетите вече съществуват",
+    "Error deleting tag(s)" : "Грешка при изтриване на етикет(и).",
+    "Error tagging" : "Грешка при задаване на етикета.",
+    "Error untagging" : "Грешка при премахване на етикета.",
+    "Error favoriting" : "Грешка при отбелязване в любими.",
+    "Error unfavoriting" : "Грешка при премахване отбелязването в любими.",
+    "Couldn't send mail to following users: %s " : "Неуспешно изпращане на имейл до следните потребители: %s.",
+    "Repair warning: " : "Предупреждение при поправка:",
+    "Repair error: " : "Грешка при поправка:",
+    "Turned on maintenance mode" : "Режим за поддръжка е включен",
+    "Turned off maintenance mode" : "Режим за поддръжка е изключен",
+    "Updated database" : "Базата данни е обоновена",
+    "Checked database schema update" : "Обновяването на схемата на базата данни е проверено",
+    "Checked database schema update for apps" : "Обновяването на схемата на базата данни за приложения е проверено",
+    "Updated \"%s\" to %s" : "Обновен \"%s\" до %s",
     "Sunday" : "Неделя",
     "Monday" : "Понеделник",
     "Tuesday" : "Вторник",
@@ -104,8 +111,6 @@ OC.L10N.register(
     "Expiration" : "Изтичане",
     "Expiration date" : "Дата на изтичане",
     "Choose a password for the public link" : "Изберете парола за общодостъпната връзка",
-    "Sending ..." : "Изпращане ...",
-    "Email sent" : "Електронната поща е изпратена",
     "Resharing is not allowed" : "Повторно споделяне не е разрешено.",
     "Share link" : "Връзка за споделяне",
     "Link" : "Връзка",
@@ -114,6 +119,8 @@ OC.L10N.register(
     "Allow editing" : "Позволяване на редактиране",
     "Email link to person" : "Имейл връзка към човек",
     "Send" : "Изпращане",
+    "Sending ..." : "Изпращане ...",
+    "Email sent" : "Електронната поща е изпратена",
     "Shared with you and the group {group} by {owner}" : "Споделено от {owner} с Вас и групата {group} .",
     "Shared with you by {owner}" : "Споделено с Вас от {owner}.",
     "group" : "група",
@@ -142,9 +149,7 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Здравей {name}, времето е {weather}",
     "Hello {name}" : "Здравейте, {name}",
     "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
-    "Updating {productName} to version {version}, this may take a while." : "Обновяване на {productName} към версия {version}. Това може да отнеме време.",
     "Please reload the page." : "Моля, презаредете страницата.",
-    "The update was unsuccessful. " : "Обновяването бе неуспешно.",
     "The update was successful. Redirecting you to ownCloud now." : "Обновяването е успешно. Сега Ви пренасочваме към ownCloud.",
     "Searching other places" : "Търсене в други места",
     "Personal" : "Лични",
@@ -152,13 +157,6 @@ OC.L10N.register(
     "Apps" : "Приложения",
     "Admin" : "Админ",
     "Help" : "Помощ",
-    "Error loading tags" : "Грешка при зареждане на етикети",
-    "Tag already exists" : "Етикетите вече съществуват",
-    "Error deleting tag(s)" : "Грешка при изтриване на етикет(и).",
-    "Error tagging" : "Грешка при задаване на етикета.",
-    "Error untagging" : "Грешка при премахване на етикета.",
-    "Error favoriting" : "Грешка при отбелязване в любими.",
-    "Error unfavoriting" : "Грешка при премахване отбелязването в любими.",
     "Access forbidden" : "Достъпът е забранен",
     "File not found" : "Файлът не е открит",
     "The specified document has not been found on the server." : "Избраният документ не е намерен на сървъра.",
@@ -180,7 +178,6 @@ OC.L10N.register(
     "Line: %s" : "Линия: %s",
     "Trace" : "Проследяване на грешките",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашата директория за данни и файлове Ви вероятно са достъпни от интернет, поради това, че файлът \".htaccess\" не функционира.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "За информация как правилно да настроиш сървъра си, моля прегледай <a href=\"%s\" target=\"_blank\">документацията</a>.",
     "Create an <strong>admin account</strong>" : "Създаване на <strong>администраторски профил</strong>.",
     "Username" : "Потребителско име",
     "Storage & database" : "Дисково пространство и база данни",
