@@ -1,21 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Не можев да пратам порака на следниве корисници: %s",
-    "Preparing update" : "Ја подготвувам надградбата",
-    "Turned on maintenance mode" : "Вклучен е модот за одржување",
-    "Turned off maintenance mode" : "Ислкучен е модот за одржување",
-    "Maintenance mode is kept active" : "Модот за одржување е уште активен",
-    "Updating database schema" : "Ја надградувам шемата на базата на податоци",
-    "Updated database" : "Базата е надградена",
-    "Checked database schema update" : "Проверена е шемата за ажурурање на базата на податоци",
-    "Checked database schema update for apps" : "Проверена е шемата за ажурурање на базата на податоци за апликации",
-    "Updated \"%s\" to %s" : "Ажурирано е \"%s\" во %s",
-    "Repair warning: " : "Предупредувања при поправка:",
-    "Repair error: " : "Грешка при поправка:",
-    "%s (3rdparty)" : "%s (3-та страна)",
-    "%s (incompatible)" : "%s (некомпатибилен)",
-    "Already up to date" : "Веќе ажурирано",
     "File is too big" : "Датотеката е пре голема",
     "Invalid file provided" : "Дадена е невалидна датотека",
     "No image or file provided" : "Не е доставена фотографија или датотека",
@@ -27,6 +12,27 @@ OC.L10N.register(
     "Crop is not square" : "Сечењето не е правоаголно",
     "%s password reset" : "%s ресетирање на лозинката",
     "Couldn't send reset email. Please contact your administrator." : "Не можам да истпратам порака за ресетирање. Ве молам контактирајте го вашиот администратор.",
+    "Error loading tags" : "Грешка при вчитување на таговите",
+    "Tag already exists" : "Тагот веќе постои",
+    "Error deleting tag(s)" : "Грешка при бришење на таго(вите)",
+    "Error tagging" : "Грешка при тагување",
+    "Error untagging" : "Грешка при отстранување на таговите",
+    "Error favoriting" : "Грешка при ",
+    "Couldn't send mail to following users: %s " : "Не можев да пратам порака на следниве корисници: %s",
+    "Preparing update" : "Ја подготвувам надградбата",
+    "Repair warning: " : "Предупредувања при поправка:",
+    "Repair error: " : "Грешка при поправка:",
+    "Turned on maintenance mode" : "Вклучен е модот за одржување",
+    "Turned off maintenance mode" : "Ислкучен е модот за одржување",
+    "Maintenance mode is kept active" : "Модот за одржување е уште активен",
+    "Updating database schema" : "Ја надградувам шемата на базата на податоци",
+    "Updated database" : "Базата е надградена",
+    "Checked database schema update" : "Проверена е шемата за ажурурање на базата на податоци",
+    "Checked database schema update for apps" : "Проверена е шемата за ажурурање на базата на податоци за апликации",
+    "Updated \"%s\" to %s" : "Ажурирано е \"%s\" во %s",
+    "%s (3rdparty)" : "%s (3-та страна)",
+    "%s (incompatible)" : "%s (некомпатибилен)",
+    "Already up to date" : "Веќе ажурирано",
     "Sunday" : "Недела",
     "Monday" : "Понеделник",
     "Tuesday" : "Вторник",
@@ -116,8 +122,6 @@ OC.L10N.register(
     "Expiration" : "Истекување",
     "Expiration date" : "Рок на траење",
     "Choose a password for the public link" : "Одбери лозинка за јавниот линк",
-    "Sending ..." : "Праќање...",
-    "Email sent" : "Е-порака пратена",
     "Resharing is not allowed" : "Повторно споделување не е дозволено",
     "Share link" : "Сподели ја врската",
     "Link" : "Линк",
@@ -126,6 +130,8 @@ OC.L10N.register(
     "Allow editing" : "Овозможи уредување",
     "Email link to person" : "Прати врска по е-пошта на личност",
     "Send" : "Прати",
+    "Sending ..." : "Праќање...",
+    "Email sent" : "Е-порака пратена",
     "Shared with you and the group {group} by {owner}" : "Споделено со Вас и групата {group} од {owner}",
     "Shared with you by {owner}" : "Споделено со Вас од {owner}",
     "group" : "група",
@@ -138,12 +144,8 @@ OC.L10N.register(
     "change" : "промени",
     "delete" : "избриши",
     "access control" : "контрола на пристап",
-    "An error occured. Please try again" : "Се случи грешка. Обиди се повторно",
     "Share" : "Сподели",
-    "Share with users or groups …" : "Сподели со корисници или групи ...",
-    "Share with users, groups or remote users …" : "Споделено со корисници, групи или оддалечени корисници ...",
     "Warning" : "Предупредување",
-    "not assignable" : "не може да се додаде",
     "invisible" : "невидлив",
     "Delete" : "Избриши",
     "Rename" : "Преименувај",
@@ -158,18 +160,13 @@ OC.L10N.register(
     "Hello {name}" : "Здраво {name}",
     "_download %n file_::_download %n files_" : ["преземи %n датотеки","преземи %n датотеки"],
     "An error occurred." : "Се случи грешка",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Надградбата беше неуспешна. Ве молиме пријавете го овој проблем на <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "Надградбата беше успешна. Веднаш ве префрлам на вашиот ownCloud.",
     "Personal" : "Лично",
     "Users" : "Корисници",
     "Apps" : "Аппликации",
     "Admin" : "Админ",
     "Help" : "Помош",
-    "Error loading tags" : "Грешка при вчитување на таговите",
-    "Tag already exists" : "Тагот веќе постои",
-    "Error deleting tag(s)" : "Грешка при бришење на таго(вите)",
-    "Error tagging" : "Грешка при тагување",
-    "Error untagging" : "Грешка при отстранување на таговите",
-    "Error favoriting" : "Грешка при ",
     "Access forbidden" : "Забранет пристап",
     "File not found" : "Датотеката не е пронајдена",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Здраво,\n\nСамо да ве известам дека  %s shared %s with you.\nView it: %s\n\n",
@@ -203,7 +200,6 @@ OC.L10N.register(
     "Search" : "Барај",
     "Server side authentication failed!" : "Автентификацијата на серверската страна е неуспешна!",
     "Please contact your administrator." : "Ве молиме контактирајте го вашиот администратор.",
-    "An internal error occured." : "Се случи интерна грешка",
     "Log in" : "Најава",
     "Wrong password. Reset it?" : "Погрешна лозинка. Да ја ресетирам?",
     "Wrong password." : "Погрешна лозинка.",
@@ -216,8 +212,6 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте го вашиот систем администратор до колку оваа порака продолжи да се појавува или пак се појавува ненадејно.",
     "Thank you for your patience." : "Благодариме на вашето трпение.",
     "These apps will be updated:" : "Следните апликации чќе бидат надградени:",
-    "Start update" : "Започни ја надградбата",
-    "Error loading file picker template: {error}" : "Грешка при вчитување на образецот за одбирач на датотеки: {error}",
-    "Password can not be changed. Please contact your administrator." : "Лозинката не може да се промени. Ве молам контактирајте го вашиот администратор."
+    "Start update" : "Започни ја надградбата"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
