@@ -24,31 +24,9 @@
  *
  */
 
-// Show warning if a PHP version below 5.4.0 is used, this has to happen here
-// because base.php will already use 5.4 syntax.
-if (version_compare(PHP_VERSION, '5.4.0') === -1) {
-	echo 'This version of ownCloud requires at least PHP 5.4.0<br/>';
-	echo 'You are currently running ' . PHP_VERSION . '. Please update your PHP version.';
-	return;
-}
-
-// Show warning if PHP 7.1 is used as ownCloud is not compatible with PHP 7.1 until
-// version 9.2.0.
-if (version_compare(PHP_VERSION, '7.1.0') !== -1) {
-	echo 'This version of ownCloud is not compatible with PHP 7.1.<br/>';
-	echo 'You are currently running ' . PHP_VERSION . '. Please use at least ownCloud 9.2.0.';
-	return;
-}
-
-// running oC on Windows is unsupported since 8.1, this has to happen here because
-// is seems that the autoloader on Windows fails later and just throws an exception.
-if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
-	echo 'ownCloud Server does not support Microsoft Windows.';
-	return;
-}
 
 try {
-	
+
 	require_once 'lib/base.php';
 
 	OC::handleRequest();
