@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que el ejemplo de configuración ha sido copiado. Esto puede arruinar su instalación y es un caso para el que no se brinda soporte. Lea la documentación antes de hacer cambios en config.php",
     "PHP %s or higher is required." : "Se requiere PHP %s o superior.",
     "PHP with a version lower than %s is required." : "PHP con una versión inferior que %s la requerida.",
+    "%sbit or higher PHP required." : "Se requiere PHP %sbit o superior.",
     "Following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
     "The command line tool %s could not be found" : "No se encontró la herramienta %s de línea de comandos",
     "The library %s is not available." : "La biblioteca %s no está disponible",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
     "ownCloud %s or higher is required." : "Se requiere ownCloud %s o superior.",
     "ownCloud %s or lower is required." : "Se requiere ownCloud %s o una versión inferior.",
-    "Help" : "Ayuda",
-    "Personal" : "Personal",
-    "Users" : "Usuarios",
-    "Admin" : "Administración",
-    "Recommended" : "Recomendado",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "La App \"%s\" no puede ser instalada porque no es compatible con esta versión de ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La app \"%s\" no puede instalarse porque las siguientes dependencias no están cumplimentadas: %s",
-    "No app name specified" : "No se ha especificado nombre de la aplicación",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "today" : "hoy",
@@ -37,7 +30,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
     "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
     "seconds ago" : "hace segundos",
-    "web services under your control" : "Servicios web bajo su control",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Módulo con id: %s no existe. Por favor habilítelo en los ajustes de sus aplicaciones o contáctese con su administrador.",
     "Empty filename is not allowed" : "No se puede dejar el nombre en blanco.",
     "Dot files are not allowed" : "Los archivos Dot no están permitidos",
@@ -45,8 +37,6 @@ OC.L10N.register(
     "File name is a reserved word" : "El nombre de archivo es una palabra reservada",
     "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
     "File name is too long" : "El nombre del archivo es demasiado largo",
-    "File is currently busy, please try again later" : "Archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
-    "Can't read file" : "No se puede leer archivo",
     "App directory already exists" : "El directorio de la aplicación ya existe",
     "Can't create app folder. Please fix permissions. %s" : "No se puede crear la carpeta de la aplicación. Corrija los permisos. %s",
     "Archive does not contain a directory named %s" : "El archivo no contiene un directorio llamado %s",
@@ -56,15 +46,13 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Los ficheros de tipo %s no son soportados",
     "Failed to open archive when installing app" : "Falló la apertura ded fichero mientras se instalaba la aplicación",
     "App does not provide an info.xml file" : "La aplicación no suministra un fichero info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "La app no puede ser instalada debido a que no se puede leer la información de la app.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "La firma no pudo ser evaluada. Por favor, contacte con el desarrollador de la aplicación y compruebe su pantalla de administración.",
     "App can't be installed because of not allowed code in the App" : "La aplicación no puede ser instalada por tener código no autorizado en la aplicación",
     "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "La App no se puede instalar debido a que la versión de info.xml no es la misma que la versión reportada por la App Store.",
-    "Application is not enabled" : "La aplicación no está habilitada",
-    "Authentication error" : "Error de autenticación",
-    "Token expired. Please reload page." : "Token expirado. Por favor, recarge la página.",
-    "Unknown user" : "Usuario desconocido",
+    "%s enter the database username and name." : "%s introduzca el nombre de usuario y la contraseña de la BBDD.",
     "%s enter the database username." : "%s ingresar el usuario de la base de datos.",
     "%s enter the database name." : "%s ingresar el nombre de la base de datos",
     "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
@@ -110,10 +98,12 @@ OC.L10N.register(
     "Sharing backend for %s not found" : "Motor compartido para %s no encontrado",
     "Sharing failed, because the user %s is the original sharer" : "Se ha fallado al compartir, ya que el usuario %s es el compartidor original",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Se ha fallado al compartir %s, ya que los permisos superan los permisos otorgados a %s",
-    "Sharing %s failed, because resharing is not allowed" : "Se ha fallado al compartir %s, ya que volver a compartir no está permitido",
+    "Sharing %s failed, because resharing is not allowed" : "Fallo al compartir %s, ya que no está permitido volverlo a compartir",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se ha fallado al compartir %s porque el motor compartido para %s podría no encontrar su origen",
     "Sharing %s failed, because the file could not be found in the file cache" : "Se ha fallado al compartir %s, ya que el archivo no pudo ser encontrado en el cache de archivo",
     "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
+    "Files can't be shared with delete permissions" : "Los archivos no pueden ser compartidos con permisos de borrado",
+    "Files can't be shared with create permissions" : "Los arhivos no pueden ser compartidos con permisos de creación",
     "Expiration date is in the past" : "Ha pasado la fecha de caducidad",
     "Cannot set expiration date more than %s days in the future" : "No se puede fijar la fecha de caducidad más de %s días en el futuro.",
     "Could not find category \"%s\"" : "No puede encontrar la categoría \"%s\"",
@@ -123,6 +113,24 @@ OC.L10N.register(
     "Username contains whitespace at the beginning or at the end" : "El nombre de usuario contiene espacios en blanco al principio o al final",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
     "The username is already being used" : "El nombre de usuario ya está en uso",
+    "Login canceled by app" : "Login cancelado por la app",
+    "User disabled" : "Usuario deshabilitado",
+    "Help" : "Ayuda",
+    "Personal" : "Personal",
+    "Users" : "Usuarios",
+    "Admin" : "Administración",
+    "Recommended" : "Recomendado",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "La app \"%s\" no puede ser instalada debido a que no se puede leer la información de la app.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "La App \"%s\" no puede ser instalada porque no es compatible con esta versión de ownCloud.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La app \"%s\" no puede instalarse porque las siguientes dependencias no están cumplimentadas: %s",
+    "No app name specified" : "No se ha especificado nombre de la aplicación",
+    "web services under your control" : "Servicios web bajo su control",
+    "File is currently busy, please try again later" : "Archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
+    "Can't read file" : "No se puede leer archivo",
+    "Application is not enabled" : "La aplicación no está habilitada",
+    "Authentication error" : "Error de autenticación",
+    "Token expired. Please reload page." : "Token expirado. Por favor, recarge la página.",
+    "Unknown user" : "Usuario desconocido",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "No están instalados los drivers de BBDD  (sqlite, mysql, o postgresql)",
     "Microsoft Windows Platform is not supported" : "La plataforma Microsoft Windows no está soportada",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "No está soportado ejecutar el servidor ownCloud en la plataforma Microsoft Windows. Sugerimos que utilice un servidor GNU/Linux en una máquina virtual si no posee opción de migrar de servidor. Encuentre paquetes de GNU/Linux así como implementar máquinas virtuales en <a href=\"%s\">%s</a>. Para migrar instalaciones actuales hacia GNU/Linux puede encontrar algunos consejos y un script de migración en <a href=\"%s\">nuestra documentación</a>.",
@@ -130,7 +138,7 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "No se puede escribir en el directorio de \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Esto puede solucionarse fácilmente %sdándole permisos de escritura al servidor en el directorio%s de apps o deshabilitando la tienda de apps en el archivo de configuración.",
     "Cannot create \"data\" directory (%s)" : "No puedo crear del directorio \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Esto puede ser solucionado <a href=\"%s\" target=\"_blank\">dando al servidor web permisos de escritura en el directorio raíz</a>.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Normalmente esto se puede solucionar  <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dándole al servidor web permisos de escritura en todo el directorio o el directorio 'root'</a>",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Los permisos normalmente puede solucionarse %sdándole al servidor permisos de escritura del directorio raíz%s.",
     "Setting locale to %s failed" : "Falló la activación del idioma %s ",
     "Please install one of these locales on your system and restart your webserver." : "Instale uno de estos idiomas en su sistema y reinicie su servidor web.",
@@ -140,6 +148,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Ajustando esta opción en php.ini permitirá que ownCloud vuelva a funcionar",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está dispuesta en \"%s\" en lugar del valor esperado \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para solucionarlo, defina la función <code>mbstring.func_overload</code> a <code>0</code> en su php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 es requerido en esta o en versiones superiores. Ahora mismo tienes instalada %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este error, actualiza la versión de tu libxml2 y reinicia el servidor web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones principales estén inaccesibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Probablemente esto venga a causa de la caché o un acelerador, tales como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Los módulos PHP se han instalado, pero aparecen listados como si faltaran",
