@@ -349,11 +349,7 @@ Raw output
 	protected function isEndOfLive() {
 		$eol = false;
 
-		//PHP 5.4 is EOL on 14 Sep 2015
-		if (version_compare(PHP_VERSION, '5.5.0') === -1) {
-			$eol = true;
-			return $eol;
-		}
+        // Red Hat support PHP so don't EOL
 		return $eol;
 	}
 }
