@@ -1,26 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Попередження безпеки та налаштування",
-    "Sharing" : "Спільний доступ",
-    "Server-side encryption" : "Шифрування на сервері",
-    "External Storage" : "Зовнішні сховища",
-    "Cron" : "Планувальник Cron",
-    "Email server" : "Сервер електронної пошти",
-    "Log" : "Журнал",
-    "Tips & tricks" : "Поради і трюки",
-    "Updates" : "Оновлення",
-    "Couldn't remove app." : "Неможливо видалити додаток.",
-    "Language changed" : "Мову змінено",
-    "Invalid request" : "Некоректний запит",
-    "Authentication error" : "Помилка автентифікації",
-    "Admins can't remove themself from the admin group" : "Адміністратор не може видалити себе з групи адміністраторів",
-    "Unable to add user to group %s" : "Не вдалося додати користувача у групу %s",
-    "Unable to remove user from group %s" : "Не вдалося видалити користувача із групи %s",
-    "Couldn't update app." : "Не вдалося оновити додаток. ",
     "Wrong password" : "Невірний пароль",
     "No user supplied" : "Користувача не вказано",
+    "Authentication error" : "Помилка автентифікації",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Будь ласка введіть пароль відновлення адміністратора, інакше всі дані будуть втрачені",
     "Wrong admin recovery password. Please check the password and try again." : "Невірний пароль відновлення адміністратора.  Будь ласка, перевірте пароль та спробуйте ще раз.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend не підтримує зміну паролів, але користувацький ключ шифрування було успішно змінено",
@@ -52,6 +35,23 @@ OC.L10N.register(
     "Email saved" : "Адресу збережено",
     "Your full name has been changed." : "Ваше повне ім'я було змінено",
     "Unable to change full name" : "Неможливо змінити повне ім'я",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Попередження безпеки та налаштування",
+    "Sharing" : "Спільний доступ",
+    "Server-side encryption" : "Шифрування на сервері",
+    "External Storage" : "Зовнішні сховища",
+    "Cron" : "Планувальник Cron",
+    "Email server" : "Сервер електронної пошти",
+    "Log" : "Журнал",
+    "Tips & tricks" : "Поради і трюки",
+    "Updates" : "Оновлення",
+    "Couldn't remove app." : "Неможливо видалити додаток.",
+    "Language changed" : "Мову змінено",
+    "Invalid request" : "Некоректний запит",
+    "Admins can't remove themself from the admin group" : "Адміністратор не може видалити себе з групи адміністраторів",
+    "Unable to add user to group %s" : "Не вдалося додати користувача у групу %s",
+    "Unable to remove user from group %s" : "Не вдалося видалити користувача із групи %s",
+    "Couldn't update app." : "Не вдалося оновити додаток. ",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ви дійсно бажаєте додати \"{domain}\" як довірений домен?",
     "Add trusted domain" : "Додати довірений домен",
     "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
@@ -78,7 +78,6 @@ OC.L10N.register(
     "Error while uninstalling app" : "Помилка видалення додатка",
     "Uninstall" : "Видалити",
     "App update" : "Оновлення додатку",
-    "No apps found for \"{query}\"" : "Не знайдено додатків для \"{query}\"",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
     "Valid until {date}" : "Дійсно до {date}",
     "Delete" : "Видалити",
@@ -103,6 +102,7 @@ OC.L10N.register(
     "A valid password must be provided" : "Потрібно задати вірний пароль",
     "A valid email must be provided" : "Вкажіть дійсний email",
     "__language_name__" : "__language_name__",
+    "Unlimited" : "Необмежено",
     "Personal info" : "Особиста інформація",
     "Sync clients" : "Клієнти синхронізації",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Усі (критичні проблеми, помилки, попередження, інформаційні, налагодження)",
@@ -130,10 +130,10 @@ OC.L10N.register(
     "Open documentation" : "Відкрити документацію",
     "Allow apps to use the Share API" : "Дозволити програмам використовувати API спільного доступу",
     "Allow users to share via link" : "Дозволити користувачам ділитися через посилання",
-    "Enforce password protection" : "Захист паролем обов'язковий",
     "Allow public uploads" : "Дозволити публічне завантаження",
-    "Allow users to send mail notification for shared files" : "Дозволити користувачам сповіщати листами про спільний доступ до файлів",
+    "Enforce password protection" : "Захист паролем обов'язковий",
     "Set default expiration date" : "Встановити термін дії за замовчуванням",
+    "Allow users to send mail notification for shared files" : "Дозволити користувачам сповіщати листами про спільний доступ до файлів",
     "Expire after " : "Скінчиться через",
     "days" : "днів",
     "Enforce expiration date" : "Термін дії обов'язковий",
@@ -226,6 +226,9 @@ OC.L10N.register(
     "Change password" : "Змінити пароль",
     "Language" : "Мова",
     "Help translate" : "Допомогти з перекладом",
+    "Name" : "Ім’я",
+    "Username" : "Ім'я користувача",
+    "Done" : "Готово",
     "Get the apps to sync your files" : "Отримати додатки для синхронізації ваших файлів",
     "Desktop client" : "Клієнт для ПК",
     "Android app" : "Android-додаток",
@@ -238,7 +241,6 @@ OC.L10N.register(
     "Show user backend" : "Показати користувача",
     "Send email to new user" : "Надіслати email новому користувачу",
     "Show email address" : "Показати адресу електронної пошти",
-    "Username" : "Ім'я користувача",
     "E-Mail" : "Адреса електронної пошти",
     "Create" : "Створити",
     "Admin Recovery Password" : "Пароль адміністратора для відновлення",
@@ -249,7 +251,6 @@ OC.L10N.register(
     "Admins" : "Адміністратори",
     "Default Quota" : "Квота за замовчуванням",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Будь ласка, вкажіть розмір сховища (наприклад: \"512 MB\" або \"12 GB\")",
-    "Unlimited" : "Необмежено",
     "Other" : "Інше",
     "Full Name" : "Повне Ім'я",
     "Group Admin for" : "Адміністратор групи",
